#
# spec file for package yast2-users
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-users
Version:        4.2.11
Release:        lp152.1.1
Summary:        YaST2 - User and Group Configuration
License:        GPL-2.0-only
Group:          System/YaST
URL:            https://github.com/yast/yast-users

Source0:        %{name}-%{version}.tar.bz2

BuildRequires:  cracklib-devel
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  perl-Digest-SHA1
BuildRequires:  perl-XML-Writer
BuildRequires:  update-desktop-files
# CLI readonly
BuildRequires:  yast2 >= 4.2.57
BuildRequires:  yast2-core-devel
BuildRequires:  yast2-devtools >= 4.2.2
BuildRequires:  yast2-perl-bindings
BuildRequires:  yast2-security
BuildRequires:  yast2-testsuite
BuildRequires:  rubygem(%rb_default_ruby_abi:rspec)

Requires:       cracklib
Requires:       perl-Digest-SHA1
Requires:       perl-X500-DN
Requires:       perl-gettext
Requires:       yast2-country

# Autologin.supported?
Requires:       yast2-pam >= 4.2.0

Requires:       yast2-security

# y2usernote, y2useritem
Requires:       yast2-perl-bindings >= 2.18.0

# this forces using yast2-ldap with correct LDAP object names (fate#303596)
Requires:       yast2-ldap >= 3.1.2

# CLI readonly
Requires:       yast2 >= 4.2.57
# cryptsha256, cryptsha516
Requires:       yast2-core >= 2.21.0

Requires:       yast2-ruby-bindings >= 1.0.0
Obsoletes:      yast2-users-devel-doc
Conflicts:      autoyast2 < 3.1.92
# older storage uses removed deprecated method, see https://github.com/yast/yast-storage/pull/187
Conflicts:      yast2-storage < 3.1.75

%description
This package provides GUI for maintenance of linux users and groups.

%prep
%setup -q

%build
%yast_build

%install
# make testsuite/modules/Ldap.rb visible
export Y2BASE_Y2DIR=`pwd`/testsuite
%yast_install
%yast_metainfo

%files
%{yast_clientdir}
%{yast_desktopdir}
%{yast_metainfodir}
%{yast_moduledir}
%{yast_yncludedir}
%{yast_libdir}
%{yast_schemadir}
#agents:
%{yast_scrconfdir}
%{yast_agentdir}
%{yast_plugindir}
%{yast_icondir}
%license COPYING
%doc %{yast_docdir}

%changelog
* Wed May 13 2020 schubi@suse.de
- AY proposal: Fixed crash. Showing user settings only because the
  UI does not fit to the AY settings. The user cannot change these
  settings anymore (bsc#1170815).
- 4.2.11
* Thu Mar 12 2020 Knut Anderssen <kanderssen@suse.com>
- Request confirmation for aborting in the dialog for setting the
  root password (bsc#1165506)
- 4.2.10
* Tue Feb  4 2020 Josef Reidinger <jreidinger@suse.com>
- Mark users as WSL capable module (bsc#1162650)
- 4.2.9
* Fri Jan 24 2020 Josef Reidinger <jreidinger@suse.com>
- Fix return code for `yast2 users list` and `yast2 users show`
  (bsc#1143516)
- 4.2.8
* Thu Jan 16 2020 Ludwig Nussel <lnussel@suse.de>
- Disable block device selector in WSL (boo#1154238)
- 4.2.7
* Mon Nov 25 2019 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- bsc#1155735, bsc#1157541:
  - Read /usr/etc/login.defs.
  - Write login.defs configuration to /etc/login.defs.d/.
- 4.2.6
* Tue Aug 27 2019 schubi@suse.de
- Set X-SuSE-YaST-AutoInstResource in desktop file (bsc#144894).
- 4.2.5
* Thu Jul 11 2019 Steffen Winterfeldt <snwint@suse.com>
- hide all password fields in log (bsc#1141017)
- 4.2.4
* Wed Jun 19 2019 Ladislav Slezák <lslezak@suse.cz>
- Fixed failing old testsuite: do not depend on the environment,
  skip nscd restart in Mode.test() (bsc#1138668)
- 4.2.3
* Fri May 31 2019 Stasiek Michalski <hellcp@mailbox.org>
- Add metainfo (fate#319035)
- Revamp spec
- Replace GenericName with Comment
- 4.2.2
* Thu May 16 2019 David Diaz <dgonzalez@suse.com>
- Fix the user creation in the installed systems, obeying the
  decision about creating the user's home as a plain directory
  or as a Btrfs subvolume (bsc#1134970).
- 4.2.1
* Tue Apr 16 2019 Stefan Hundhammer <shundhammer@suse.com>
- Offer autologin only if a display manager that supports it is
  installed (bsc#1128385)
- 4.2.0
* Mon Apr 15 2019 schubi@suse.de
- AY creating user: Improved checking of already existing home
  directories (bsc#1130158)
- 4.1.12
* Mon Mar 11 2019 schubi@suse.de
- Added tag home_btrfs_subvolume to *.rnc file (bsc#1128707)
- Improved error message layout while creating btrfs subvolumes.
- 4.1.11
* Thu Feb 28 2019 schubi@suse.de
- Removed "btrfs_subvolume" from user default values (bsc#1125779)
- Added AutoYaST support for home Btrfs subvolumes.
- 4.1.10
* Wed Feb 27 2019 mvidner@suse.com
- Delete remaining dead code for encrypted homes
  (bsc#1127138, fate#323541).
- 4.1.9
* Mon Feb 18 2019 schubi@suse.de
- Fixed console warning produced by Users.pm module.
  (bsc#1121070)
  Fixed typo CRACKLIB_DICT_PATH in security setting.
- 4.1.8
* Mon Feb 11 2019 dgonzalez@suse.com
- Allow to create the user home directory as Btrfs subvolume
  (fate#316134).
- 4.1.7
* Fri Jan 11 2019 igonzalezsosa@suse.com
- Fixed call to renamed method (bsc#1121473).
- 4.1.6
* Tue Jan  8 2019 mvidner@suse.com
- Fixed a syntax error in UsersPluginQuota.pm introduced
  in the previous change (bsc#1118291).
- 4.1.5
* Thu Dec 20 2018 Josef Reidinger <jreidinger@suse.com>
- always use absolute path to binaries (bsc#1118291)
- properly escape shell arguments (bsc#1118291)
- 4.1.4
* Wed Dec 19 2018 schubi@suse.de
- Improved layout for root password screen mask (bsc#1119671).
- 4.1.3
* Thu Dec  6 2018 schubi@suse.de
- Label for importing public SSH key changed (bsc#1118617).
- 4.1.2
* Thu Nov 29 2018 dgonzalez@suse.com
- Allow to import, during the installation, users from the more
  recently accessed Linux installation in the system (bsc#1048983)
- 4.1.1
* Mon Nov 26 2018 Noah Davis <noahadvs@gmail.com>
- Provide icon with module (boo#1109310)
- 4.1.0
* Wed Nov 21 2018 Stefan Hundhammer <shundhammer@suse.com>
- Allow system role to default to no local user (Fate#326447)
* Mon Nov 12 2018 igonzalezsosa@suse.com
- Improve public key selector help (related to fate#324690).
- 4.0.10
* Fri Nov  9 2018 igonzalezsosa@suse.com
- Add public keys handling support in an installed system
  (related to fate#324690).
- 4.0.9
* Fri Nov  2 2018 igonzalezsosa@suse.com
- Allow the root user to use a public key for authentication
  (fate#324690).
- 4.0.8
* Fri Oct 19 2018 snwint@suse.com
- read ssh keys from root user only if the user exists (bsc#1112119,
  bsc#1107456)
- 4.0.7
* Mon Sep 10 2018 schubi@suse.de
- Fixed conflicting shortcuts in plugin module (bsc#1095320).
- 4.0.6
* Mon Aug 20 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
- Changed dir of COPYING file.
* Fri Apr  6 2018 igonzalezsosa@suse.com
- Do not crash if root user is not defined (bsc#1088183).
- 4.0.5
* Fri Mar 23 2018 jreidinger@suse.com
- Fix import of RootPassword if user is specified in autoyast
  profile (bsc#1081958)
- 4.0.4
* Thu Mar  1 2018 mvidner@suse.com
- Fixed removing the password expiration date (bsc#1080125)
- 4.0.3
* Tue Feb 27 2018 jreidinger@suse.com
- fix generating pot files (bsc#1083015)
- 4.0.2
* Tue Nov 28 2017 knut.anderssen@suse.com
- AutoYaST: Write and export SSH authorized keys also for root user
  (bsc#1066342).
- 4.0.1
* Wed Nov  8 2017 jsrain@suse.cz
- Remove the support for encrypting home directory (fate#323541)
- 4.0.0
* Tue Sep  5 2017 igonzalezsosa@suse.com
- Do not freeze while parsing authorized_keys (bsc#1053564)
- 3.2.12
* Thu Mar 16 2017 kanderssen@suse.com
- Fixed a string comparison in Users perl module. (bsc#1029528)
- 3.2.11
* Tue Mar  7 2017 jreidinger@suse.com
- do not ask again for already approved weak password second
  attempt, so it will work also if widget is recreated(bsc#1025835)
- 3.2.10
* Mon Feb 20 2017 jreidinger@suse.com
- do not ask again for already approved weak password (bsc#1025835)
- 3.2.9
* Fri Jan 20 2017 mvidner@suse.com
- Password widget: a compact layout, do not steal focus (FATE#322328)
- 3.2.8
* Wed Dec 14 2016 jreidinger@suse.com
- Separate root password widget and keyboard layout test widget
  (needed for FATE#321754)
- 3.2.7
* Fri Dec  2 2016 jreidinger@suse.com
- Set the focus to the first password field to keep the same
  behavior as before the last change. (for FATE#321754)
- 3.2.6
* Thu Dec  1 2016 jreidinger@suse.com
- prepare reusable widget for setting root password
  (needed for FATE#321754)
- 3.2.5
* Tue Oct 11 2016 hguo@suse.com
- Fix the invocation of authentication configuration instance
  (bsc#1000749).
- 3.2.4
* Tue Oct 11 2016 ancor@suse.com
- Corrected version numbers to correctly coordinate Leap 42.2,
  SLE-12-SP2 maintenance updates and Tumbleweed.
- Needed to release the fix for bsc#1000749
* Tue Oct  4 2016 schubi@suse.de
- Checking all possible /home mount points (/mnt/home and /home).
  (bnc#995299)
- 3.2.3
* Wed Sep 21 2016 mvidner@suse.com
- Do not require yast2-ldap for build time tests (bsc#999203).
- 3.2.2
* Tue Sep 20 2016 igonzalezsosa@suse.com
- Prevent a potential security issue if the target authorized_keys
  file is not a regular file (related to FATE#319471)
- Fix authorized_keys section of AutoYaST schema
- 3.2.1
* Fri Sep 16 2016 igonzalezsosa@suse.com
- Add support to specify SSH authorized keys in the profile
  (FATE#319471)
- 3.2.0
* Fri Sep  2 2016 schubi@suse.de
- AutoYaST: Ignore Users without UID while checking for duplicate
  UIDs (bnc#996823)
- 3.1.57
* Tue Aug 30 2016 schubi@suse.de
- AutoYaST: Checking users entries for duplicate username/UIDs.
  (bnc#995397)
- 3.1.56
* Fri Aug 12 2016 ancor@suse.com
- The YaST client using the user creation dialog can now know
  which action was selected by the user (needed to fix bsc#992245)
- 3.1.55
* Thu Aug 11 2016 ancor@suse.com
- Fixed the installation dialog for user creation so it works
  also in YaST Firstboot (needed to fix bsc#992245)
- 3.1.54
* Mon Jun 27 2016 igonzalezsosa@suse.com
- Fix creation of the first user account during installation
  (bsc#986542)
- 3.1.53
* Wed Jun  1 2016 cwh@suse.com
- Removed devel-doc package (fate#320356)
- 3.1.52
* Mon May 23 2016 igonzalezsosa@suse.com
- Fix a string concatenation in Users.pm relative introduced in
  bsc#980878.
- 3.1.51
* Mon May 23 2016 igonzalezsosa@suse.com
- Fix detection of mounted /home partition during installation
  (bsc#980878)
- 3.1.50
* Thu May  5 2016 ancor@suse.com
- Make user import work even if passwd and shadow files are not
  copied to /var/lib/YaST2 via "copy_to_system" (part of
  fate#319624)
- 3.1.49
* Thu May  5 2016 igonzalezsosa@suse.com
- Fix users import when entries for all non-system users are missing in
  /etc/shadow (bsc#978648)
- 3.1.48
* Thu Apr  7 2016 igonzalezsosa@suse.com
- Does not set empty passwords fields in /etc/shadow during
  installation (CVE-2016-1601, bnc#973639, bnc#974220)
- Set root password correctly when using a minimal profile
  (bnc#971804)
- 3.1.47
* Sat Mar  5 2016 igonzalezsosa@suse.com
- Do not include inst-sys users when cloning the configuration
  after the installation (bnc#965852)
- 3.1.46
* Thu Feb 18 2016 schubi@suse.de
- Do not crash autoinstallation if the home directory of a user is
  directly under /.
  (bnc#966867)
- 3.1.45
* Thu Feb  4 2016 jreidinger@suse.com
- Drop the Receive System Mail checkbox from the installation
  workflow (FATE#320448)
- 3.1.44
* Fri Jan 29 2016 ancor@suse.com
- Small visual improvements in the "local user" installation
  dialog (bsc#893825)
- 3.1.43
* Wed Jan 27 2016 ancor@suse.com
- Redesign of the installation dialogs (bsc#893825)
- 3.1.42
* Wed Nov 18 2015 igonzalezsosa@suse.com
- fix validation of AutoYaST profiles (bsc#954412)
- 3.1.41
* Tue Sep  1 2015 igonzalezsosa@suse.com
- Move users creation to first stage during autoinstallation,
  so it is not needed to run the 2nd stage to have a minimal system
  (bnc#892091)
- 3.1.40
* Thu Jul  2 2015 igonzalezsosa@suse.com
- Allow editing password-less users (bsc#928607)
- 3.1.39
* Thu Jul  2 2015 jreidinger@suse.com
- Allow setting the root password to "0" (the digit zero)
  (bnc#930909)
- 3.1.38
* Thu Feb  5 2015 gs@suse.de
- Text mode: set F9 function key binding correctly (bnc #881396)
- 3.1.37
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
- 3.1.36
* Thu Nov 20 2014 jsuchome@suse.cz
- enable changing of cn value if LDAP user is not saved yet
  (bnc#904645)
- 3.1.35
* Thu Oct 16 2014 jsuchome@suse.cz
- fix calling auth client (bnc#901419)
- 3.1.34
* Tue Sep 23 2014 jsuchome@suse.cz
- fix the usage of tail command, so the quota state is read
  correctly (bnc#887753)
- 3.1.33
* Wed Sep  3 2014 schubi@suse.de
- Autoyast: Initialize the user hash in User module correctly
  This is needed for establishing the system users
  (espl. the root user). (bnc#893725)
- 3.1.32
* Mon Aug 25 2014 schubi@suse.de
- Autoyast: Moved minimal configuration to a central place in
  inst_finish. (bnc#886464)
- 3.1.31
* Wed Aug 13 2014 locilka@suse.com
- Fixed handling of the [Abort] button in inst_user_first, user is
  asked for confirmation (bnc#886662)
- Fixed UsersSimple.Transliterate not to return a trailing newline
- 3.1.30
* Thu Jul 31 2014 schubi@suse.de
- Checking max UID for system users correctly while importing from
  autoinst.xml. (bnc#888154)
- 3.1.29
* Tue Jul 22 2014 jsuchome@suse.cz
- Fixed 'Quota is not enabled on your system' by adapting
  to a change of the service name (bnc#887717).
- 3.1.28
* Tue Jun 10 2014 locilka@suse.com
- Fixed text layout in root-password dialog in installation
  (bnc#878248)
- 3.1.27
* Mon Jun  2 2014 schubi@suse.de
- Setting default home directory of user "root" to "/root"
  (bnc#878427)
- 3.1.26
* Fri May 23 2014 schubi@suse.de
- Generating user section in autoinst.xml file
  (bnc#877985)
- 3.1.25
* Tue May 13 2014 jsuchome@suse.cz
- added Test Keyboard Layout field into current root password dialog
  (bnc#877442)
- 3.1.24
* Wed May  7 2014 jreidinger@suse.com
- do not modify frozen text from gettext call (bnc#876571)
- 3.1.23
* Fri Apr 18 2014 mfilka@suse.com
- bnc#872903
  - fixed internal error (missing IsManaged method)
- 3.1.22
* Fri Apr  4 2014 ckornacker@suse.com
- hide Kerberos passwords from process list
- 3.1.21
* Fri Apr  4 2014 jreidinger@suse.com
- fix warning about constant redefinition (bnc#871805)
- 3.1.20
* Thu Apr  3 2014 jreidinger@suse.com
- remember user input in user dialog when going forward and back
  (bnc#865540)
- 3.1.19
* Tue Mar 25 2014 jsuchome@suse.cz
- do not encrypt already crypted password of imported user
  (bnc#869798)
- 3.1.18
* Mon Mar 17 2014 ckornacker@suse.com
- fix exception on missing yast2-auth-client module (bnc#868437)
- 3.1.17
* Thu Mar 13 2014 varkoly@suse.com
- Adapt testsuit
- 3.1.16
* Wed Mar 12 2014 varkoly@suse.com
- Add plugin for creating kerberos accounts
- Modify check for aviability of LDAP
- 3.1.15
* Mon Mar  3 2014 ckornacker@suse.com
- migrate ldap/kerberos-client to auth-client (bnc#865812)
- 3.1.14
* Fri Feb 28 2014 jsuchome@suse.cz
- skip username checks if there's user for import (bnc#866089)
- 3.1.13
* Wed Feb 26 2014 locilka@suse.com
- Fixed users plug-ins package names (bnc#865812)
- 3.1.12
* Thu Feb 20 2014 jsuchome@suse.cz
- save Autologin settings at the end of installation (bnc#863436)
- 3.1.11
* Tue Feb 18 2014 jsuchome@suse.cz
- check root's password when it is same as one for 1st user
  (bnc#864124)
- 3.1.10
* Thu Feb 13 2014 varkoly@suse.com
- BNC#863612 YaST reports Cannot find client ldap/routines.rb
- 3.1.9
* Wed Feb 12 2014 jreidinger@suse.com
- fix namespace collision leading to error message in installation
- 3.1.8
* Fri Feb  7 2014 jreidinger@suse.com
- support minimal installation(FATE#313149)
- 3.1.7
* Fri Feb  7 2014 jreidinger@suse.com
- format spec file
- versioned build requires of yast2-ldap as it is used in testsuite
- 3.1.6
* Fri Jan 31 2014 varkoly@suse.com
- Change requirement from yast2-ldap-client to yast2-ldap
- 3.1.5
* Fri Dec 13 2013 jsuchome@suse.cz
- added possibility to delete user although it has some processes
  running (bnc#849870)
* Mon Dec  9 2013 lslezak@suse.cz
- fixed "can't modify frozen String" error (bnc#854495)
- 3.1.4
* Thu Dec  5 2013 jsuchome@suse.cz
- report error if cryptconfig was not installed (bnc#853189)
* Wed Nov 13 2013 lslezak@suse.cz
- installation: removed LDAP/Kerberos autodetection,
  allow configuring only local users (FATE#314695)
- 3.1.3
* Wed Nov 13 2013 jreidinger@suse.com
- Add explicit COPYING file
* Wed Nov 13 2013 lslezak@suse.cz
- require non-empty root password in the 1st stage (configuring
  later is not possible, the 2nd stage has been removed)
* Mon Nov 11 2013 lslezak@suse.cz
- properly crypt the password for the initial user
- 3.1.2
* Wed Oct 30 2013 lslezak@suse.cz
- do not save the data for the 2nd stage, create the users
  in the 1st stage directly
- 3.1.1
* Thu Sep 19 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Wed Aug  7 2013 jsuchome@suse.cz
- do not recrypt group password provided in autoYaST profile
  (backport of bnc#722421)
- 3.0.1
* Wed Jul 31 2013 yast-devel@opensuse.org
- converted from YCP to Ruby by YCP Killer
  (https://github.com/yast/ycp-killer)
- version 3.0.0
* Mon Jul 29 2013 lslezak@suse.cz
- move the development documentation to -devel-doc subpackage,
- agent-crack documentation - install JS and CSS files created
  by doxygen
- 2.24.1
* Thu Jul  4 2013 jsuchome@suse.cz
- update testedfiles in tests (lslezak)
- 2.24.0
* Thu Mar 28 2013 jsuchome@suse.cz
- set the value of CHARACTER_CLASS, read from /etc/login.defs
  (bnc#810482)
- 2.23.5
* Tue Feb 26 2013 jsuchome@suse.cz
- correctly check for nil value (bnc#803787)
- 2.23.4
* Wed Feb  6 2013 jsuchome@suse.cz
- adapted to changes of /etc/login.defs (bnc#802006)
- 2.23.3
* Thu Jan 17 2013 jsuchome@suse.cz
- enable using no secondary groups as a default (bnc#789635)
- 2.23.2
* Thu Dec  6 2012 jsuchome@suse.cz
- replaced obsolete SuSEconfig call
- 2.23.1
* Fri Oct 19 2012 jsuchome@suse.cz
- report critical actions (adding/removing user) in syslog
- 2.23.0
* Thu Mar 29 2012 jsuchome@suse.cz
- merged proofread texts
- 2.22.4
* Thu Mar 22 2012 jsuchome@suse.cz
- User specific LDAP configuration moved here from ldap-client,
  shown as "LDAP Administration Settings" dialog (fate#313143)
- fixed Password Policy handling
- 2.22.3
* Tue Jan 31 2012 jsuchome@suse.cz
- check if security settings were not modified on read (bnc#743715)
- 2.22.2
* Thu Jan 26 2012 jsuchome@suse.cz
- reverted accidental change
- 2.22.1
* Wed Jan 25 2012 jsuchome@suse.cz
- confirmed license
- 2.22.0
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Oct 24 2011 jsuchome@suse.cz
- testsuite adapted to last change of yast2-pam
- 2.21.9
* Mon Sep 26 2011 visnov@suse.cz
- set dialog title
- 2.21.8
* Thu Sep 22 2011 jsuchome@suse.cz
- use first stage saved data only in second stage (bnc#712900)
- 2.21.7
* Fri Aug  5 2011 tgoettlicher@suse.de
- fixed .desktop file (bnc #681249)
* Wed Jul 20 2011 jsuchome@suse.cz
- remove blowfish hash from selections, make sha512 the default
  (fate#312321)
- 2.21.6
* Fri Jul 15 2011 jsuchome@suse.cz
- adapted testsuite to previous change
- 2.21.5
* Fri Jul 15 2011 jsuchome@suse.cz
- fixed typos (bnc#703227)
- 2.21.4
* Tue Apr  5 2011 jsuchome@suse.cz
- added support for SHA-2 based crypto methods (fate309705)
- 2.21.3
* Fri Apr  1 2011 jsuchome@suse.cz
- check for 'sss' in nsswitch.conf for LDAP users (bnc#683782)
* Wed Mar 23 2011 jsuchome@suse.cz
- do not abort whole installation from auth clients (bnc#678650)
- 2.21.2
* Fri Mar 11 2011 jsuchome@suse.cz
- added tests for encrypted directories
- 2.21.1
* Thu Mar 10 2011 jsuchome@suse.cz
- added possibility to take old encrypted directory by new user
  (bnc#425745)
- 2.21.0
* Thu Feb 17 2011 jsuchome@suse.cz
- do not run both 'user' and 'user_non_interactive' steps
  (bnc#672139)
- 2.20.2
* Fri Dec  3 2010 jsuchome@suse.cz
- when user is disabled, disable its autologin (bnc#653559)
- 2.20.1
* Mon Sep 13 2010 jsuchome@suse.cz
- YaPI: user_attributes also for system users (bnc#638907)
- 2.20.0
* Mon May 24 2010 jsuchome@suse.cz
- UMASK setting moved to /etc/default/useradd (bnc#606249)
- /etc/login.defs no more written
- 2/19.14
* Mon Apr 26 2010 jsuchome@suse.cz
- skip root password creation if it was already saved (bnc#599287)
- 2.19.13
* Thu Apr 22 2010 jsuchome@suse.cz
- do not read autologin settings during autoinstallation
  (bnc#596750)
- 2.19.12
* Thu Apr  8 2010 jsuchome@suse.cz
- check for autologin status also during firstboot (bnc#576899)
- 2.19.11
* Thu Apr  1 2010 jsuchome@suse.cz
- check user existence before adding to the group (bnc#592223)
- 2.19.10
* Tue Mar 30 2010 jsuchome@suse.cz
- change home directory onwer in case of GID change (bnc#592229)
- 2.19.9
* Thu Mar 18 2010 jsuchome@suse.cz
- ask for confirmation when inital root pw not entered (bnc#569322)
- 2.19.8
* Thu Mar 11 2010 jsuchome@suse.cz
- YaPI enhanced to return default values
- 2.19.7
* Wed Mar 10 2010 jsuchome@suse.cz
- YaPI: allow to specify default group by name (bnc#582254)
- 2.19.6
* Mon Mar  8 2010 jsuchome@suse.cz
- handle possible empty shadow (bnc#583338)
- 2.19.5
* Fri Feb 26 2010 jsuchome@suse.cz
- password warnings merged into one big message (bnc#571777)
- 2.19.4
* Tue Feb 16 2010 jsuchome@suse.cz
- empty hash before reading, to avoid caching problems (bnc#580167)
- 2.19.3
* Wed Jan 13 2010 kmachalkova@suse.cz
- Adjusted .desktop file(s) to wrap /sbin/yast2/ calls in xdg-su
  where root privileges are needed, removed X-KDE-SubstituteUID key
  (bnc#540627)
* Tue Dec  8 2009 jsuchome@suse.cz
- show Enabled/Disable checkbox for LDAP users only when action is
  available (bnc#557714)
- 2.19.2
* Mon Nov 30 2009 jsuchome@suse.cz
- YaPI: call newaliases after updating aliases (bnc#559135)
- 2.19.1
* Thu Nov 19 2009 jsuchome@suse.cz
- fix HTML list in proposal (bnc#544981)
- 2.19.0
* Fri Nov  6 2009 jsuchome@suse.cz
- live installation: implicit check for empty user login
- do not default secondary group list to "video" (bnc#552039)
- 2.18.15
* Thu Oct  1 2009 jsuchome@suse.cz
- add GID to autoYaST group export map in more cases (bnc#540787)
- 2.18.14
* Thu Sep 17 2009 jsuchome@suse.cz
- check for return value of extend (bnc#510999)
- 2.18.13
* Mon Sep 14 2009 jsuchome@suse.cz
- new file YaPI/ADMINISTRATOR.pm for root's password and aliases
- 2.18.12
* Thu Sep  3 2009 jsuchome@suse.cz
- added keywords to desktop file
- 2.18.11
* Thu Aug 20 2009 jsuchome@suse.cz
- text fixes: use YaST, not YaST2 (bnc#532518)
- 2.18.10
* Thu Aug 13 2009 jsuchome@suse.cz
- fixed key names in the agent for reading NIS data (bnc#526211)
- 2.18.9
* Thu Jul 16 2009 jsuchome@suse.cz
- use GetFeature instead of GetBooleanFeature to detect if the
  key is present
- 2.18.8
* Fri Jun 26 2009 jsuchome@suse.cz
- manual installation of 32bit packages packages no longer needed
  (bnc#354164)
- 2.18.7
* Fri Jun 26 2009 jsuchome@suse.cz
- YaPI: enable returing set of attributes (UsersGet, UserGet)
- 2.18.6
* Wed Jun 24 2009 jsuchome@suse.cz
- in firstboot, allow "Use this password for root" check box
  (fate#306297)
- 2.18.5
* Fri Jun 19 2009 mvidner@suse.cz
- Using autodocs-ycp.ami, which contains a fix for automake 1.11.
* Tue Jun  2 2009 jsuchome@suse.cz
- OBSCURE_CHECKS_ENAB not available from PAM since
  yast2-security-2.18.0, making related functionality YaST specific
- 2.18.4
* Tue Jun  2 2009 ug@suse.de
- RNC file is less strict for <user_defaults>
* Wed Mar 11 2009 jsuchome@suse.cz
- fixed schema file (bnc#480466)
* Fri Feb 27 2009 jsuchome@suse.cz
- transliteration of UTF-8 accented characters to ASCII during
  name generation (bnc#442225)
- 2.18.3
* Wed Feb 18 2009 jsuchome@suse.cz
- ask for disabling autologin only when adding 2nd user(bnc#332729)
* Mon Feb  9 2009 jsuchome@suse.cz
- added new logging functions which should produce human readable
  log file (fate#100386)
- 2.18.2
* Wed Feb  4 2009 jsuchome@suse.cz
- read objectClass for LDAP users every time (bnc#471971)
* Thu Jan 15 2009 jsuchome@suse.cz
- no exit confirmation popup if no changes were made (bnc#458329)
- fixed typo made in previous change
* Tue Jan  6 2009 jsuchome@suse.cz
- used String::RemoveShortcut where button labels are in the help
  texts (bnc#307220)
- 2.18.1
* Tue Dec 16 2008 jsuchome@suse.cz
- do not try to detect network authentication methods during
  firstboot (bnc#458468)
- 2.18.0
* Tue Dec  2 2008 ug@suse.de
- rnc file fixed
* Mon Dec  1 2008 jsuchome@suse.cz
- do not open user dialogs in 2nd stage if user was configured
  before (bnc#450231)
- check for network before checking for network methods (bnc#450469)
- 2.17.27
* Tue Nov 25 2008 jsuchome@suse.cz
- installation: do not reset root password when modifying 1st user
  settings (bnc#445512)
- 2.17.26
* Fri Nov 14 2008 jsuchome@suse.cz
- do not use Wizard::OpenOKDialog together with hiding Abort button
  (bnc#444176)
- 2.17.25
* Thu Nov 13 2008 jsuchome@suse.cz
- really rename 'bind.rpm' to 'bind' (bnc#438691)
- 2.17.24
* Tue Nov 11 2008 jsuchome@suse.cz
- do not move LDAP objects in the tree when not needed (bnc#434324)
- 2.17.23
* Wed Nov  5 2008 jsuchome@suse.cz
- button labels adapted to current style guide (bnc#440518)
- 2.17.22
* Fri Oct 31 2008 jsuchome@suse.cz
- delete crypted homes before writing /etc/passwd
- check for cracklib-devel in configure
- 2.17.21
* Wed Oct 29 2008 jsuchome@suse.cz
- during live installation, available package is installed one
- bind tools are in 'bind' image, not 'bind.rpm' (bnc#438691)
- 2.17.20
* Wed Oct 22 2008 jsuchome@suse.cz
- do not call extend during live installation
- 2.17.19
* Thu Oct 16 2008 jsuchome@suse.cz
- check the return value of dig command (bnc#435878)
- use domainname to get the domain name (workaround for bnc#393951)
- 2.17.18
* Mon Oct 13 2008 jsuchome@suse.cz
- added CLI option 'batchmode': do not ask for data (bnc#431685)
- 2.17.17
* Thu Oct  9 2008 jsuchome@suse.cz
- users.desktop adapted for autoYaST (bnc#430111)
- 2.17.16
* Mon Oct  6 2008 jsuchome@suse.cz
- better message when loading package into inst-sys (bnc#432298)
- fingerprint-reader: thinkfinger replaced by fp (fate#300416)
- 2.17.15
* Fri Oct  3 2008 jsuchome@suse.cz
- added autoYaST support for autologin (bnc#430111)
- UsersSimple: import Stage module before using it (bnc#431890)
- 2.17.14
* Fri Sep 19 2008 jsuchome@suse.cz
- detect authentication methods also in 2nd stage (bnc#427256)
- 2.17.13
* Wed Sep 17 2008 jsuchome@suse.cz
- load/unload bind tools during installation (bnc#425382)
- 2.17.12
* Tue Sep 16 2008 jsuchome@suse.cz
- do not try to install cryptconfig.i386 package
- 2.17.11
* Mon Sep 15 2008 jsrain@suse.cz
- adapted testsuite in order to build
- 2.17.10
* Thu Sep  4 2008 jsuchome@suse.cz
- load/unload cracklib image during installation
- 2.17.9
* Tue Sep  2 2008 jsuchome@suse.cz
- do not show installation step when the work is hidden(bnc#401319)
- 2.17.8
* Mon Sep  1 2008 jsuchome@suse.cz
- help text for directory encryption even if it is not available
- 2.17.7
* Fri Aug 29 2008 jsuchome@suse.cz
- fixed capitalization of LDAP entries (bnc#420010)
- show if the "default policy" is active (bnc#421342, rhafer)
- 2.17.6
* Fri Aug 22 2008 jsuchome@suse.cz
- fixed setting Kerberos during installation
- 2.17.5
* Wed Aug 13 2008 jsuchome@suse.cz
- detect available Kerberos and LDAP Servers during installation
  (fate#301340)
- 2.17.4
* Thu Jul 24 2008 jsuchome@suse.cz
- checkbox to force a change of password (bnc#368613)
- 2.17.3
* Mon Jul 21 2008 jsuchome@suse.cz
- do not lowecase LDAP object names (fate#303596):
  internal user/group keys (not only LDAP) adapted to new schema
- 2.17.2
* Tue Jul  8 2008 jsuchome@suse.cz
- do not mention "special characters" as password content
  (bnc#393730)
* Thu Jun 19 2008 jsuchome@suse.cz
- save the information if users were already written in 2nd stage
  of installation (bnc#395796)
- 2.17.1
* Mon Jun 16 2008 jsuchome@suse.cz
- remember root password during installation (bnc#396399)
* Fri Jun 13 2008 jsuchome@suse.cz
- set title icon in installation cliens (bnc#398335)
* Fri Jun  6 2008 jsuchome@suse.cz
- allow @ in home directory path (bnc#397811)
* Fri Jun  6 2008 jsuchome@suse.cz
- fixed typo (bnc#374628)
- 2.17.0
* Fri May 23 2008 jsuchome@suse.cz
- enable auth and user clients in 2nd stage when necessary
- ask for confirmation when 1st user creation is skipped
  (bnc#393722)
- 2.16.33
* Wed May 21 2008 jsuchome@suse.cz
- install architecture dependent cryptconfig (bnc#392028)
- 2.16.32
* Tue May 20 2008 jsuchome@suse.cz
- do not allow encrypting directories when pam_thinkfinger is used
  (bnc#390810)
- do not crypt already encrypted password when importing users
  (bnc#392053)
- ignore first user when imporing existing ones (bnc#392034)
- 2.16.31
* Fri May 16 2008 jsrain@suse.cz
- added categories Settings and System into desktop file
  (bnc #382778)
* Tue May  6 2008 jsuchome@suse.cz
- change ownership of home during autoinstallation (bnc#386329)
- 2.16.30
* Tue Apr 29 2008 jsuchome@suse.cz
- correctly set maximum password length for LDAP (bnc#384414)
- 2.16.29
* Fri Apr 18 2008 jsuchome@suse.cz
- correctly change the encryption type for root (bnc#371147)
- 2.16.28
* Wed Apr 16 2008 jsuchome@suse.cz
- during 1st stage of installation import users only once
- 2.16.27
* Wed Apr 16 2008 jsuchome@suse.cz
- changed behavior of Check functions: remember the accepted values
- changing ownership of home directory now optional (bnc#308415)
- 2.16.26
* Mon Apr 14 2008 jsuchome@suse.cz
- use SystemFilesCopy::CopyFilesToSystem to acquire /etc/passwd
  and /etc/shadow in the 1st stage (fate#302980)
- show imported users in installation summary
- 2.16.25
* Fri Apr 11 2008 jsuchome@suse.cz
- prepare API for "Import User From Previous Installation" in
  the 1st stage of installation (fate#302980)
- 2.16.24
* Fri Apr 11 2008 jsuchome@suse.cz
- better fix of bnc#373654: read system settings in inst_user
* Mon Apr  7 2008 jsuchome@suse.cz
- import the user settings before reading system ones (bnc#373654)
- 2.16.23
* Thu Apr  3 2008 jsrain@suse.cz
- save users configuration during live installation
* Tue Apr  1 2008 jsuchome@suse.cz
- propose login only from the first chunk of full name (bnc#372202)
- 2.16.22
* Mon Mar 31 2008 jsuchome@suse.cz
- use the real password in the Password fields (bnc#374787)
- change the label for the additional groups (bnc#367926)
- fixed incorrect usage of YCPValue in crack-agent (bnc#375385)
- 2.16.21
* Wed Mar 26 2008 jsuchome@suse.cz
- installation proposal: show full name and encryption method
- installation dialogs: check for default values of autologin
  and "root password = user password" options
- use new ag_anyxml for reading pam_mount.conf.xml (bnc#366867)
- use OK button label instead of Accept (fate#120373)
- 2.16.20
* Wed Mar 19 2008 jsuchome@suse.cz
- read /etc/login.defs before writing it (bnc#369287)
- 2.16.19
* Wed Mar 19 2008 jsuchome@suse.cz
- blowfish is default: adapt maximum password length (bnc#371147),
  adapted testsuite
- 2.16.18
* Wed Mar 19 2008 jsuchome@suse.cz
- do not show "*****" for empty root password
- added list of system user names to check user name conflicts
  during 1st stage of installation
- updated list of system user names for translation
- better installation proposal
- 2.16.17
* Mon Mar 17 2008 jsrain@suse.cz
- added 'StartupNotify=true' to the desktop file (bnc #304964)
* Wed Mar  5 2008 jsuchome@suse.cz
- check home directory of first user right before writing
- do not allow decrypting home when user is logged in (bnc#365547),
  remove old home directory after all critical actions are done
- added installation proposal for user settings (fate#302980)
- 2.16.16
* Wed Mar  5 2008 jsuchome@suse.cz
- during installation, check if future /home doesn't contain home
  directory for the first user and adapt UID of the user according
  to directory owner (fate#302980)
- use internal defaults if /etc/default/useradd cannot be read
  (bnc#365116)
- 2.16.15
* Fri Feb 29 2008 jsuchome@suse.cz
- fixed removing LDAP Shadow Account plugin (bnc#364833)
- 2.16.14
* Wed Feb 27 2008 jsuchome@suse.cz
- fixed enabling LDAP users with password policy (bnc#364837)
- 2.16.13
* Mon Feb 25 2008 jsuchome@suse.cz
- proposing of username uses same method on installed system
  as in installation
- first dialog handled specially in text mode
- 2.16.12
* Thu Feb 21 2008 jsuchome@suse.cz
- added dialog for root pw in first stage (FATE 302980)
- more variables and API moved from Users to UsersSimple
- 2.16.11
* Fri Feb 15 2008 jsuchome@suse.cz
- remove LDAP entries from custom settings if LDAP is not present
  in /etc/nsswitch.conf (#bnc360600)
- 2.16.10
* Fri Feb 15 2008 jsuchome@suse.cz
- moved password and user name checks to UsersSimple.pm to make
  them available during first stage of installation
- 2.16.9
* Wed Feb 13 2008 visnov@suse.cz
- show icons in users table
* Thu Jan 31 2008 jsuchome@suse.cz
- unified function names for RootAlias handling
- first steps for implementation of FATE 302980,
    "Simplified user config during installation" :
- added inst_user_first.ycp, client for user configuration in first
  stage of installation
- UsersSimple.pm is module for saving the data gathered from firs
  stage
- inst_root, inst_auth, inst_user updated to check for first stage
  configuration data
- 2.16.8
* Tue Jan 29 2008 jsuchome@suse.cz
- "User Management" is "User and Group Management" now in control
  center: group desktop file removed (F303392)
- 2.16.7
* Fri Jan 25 2008 jsuchome@suse.cz
- inst_auth: replaced deprecated NetworkDevices by NetworkInterfaces
- main UI updated for the usage of tabs (#279959)
- 2.16.6
* Thu Dec 13 2007 jsuchome@suse.cz
- allow to set delivering root's mail to user's mailbox: also
  on installed system (F302264)
- 2.16.5
* Mon Dec  3 2007 jsuchome@suse.cz
- merged texts from proofread
* Mon Dec  3 2007 jsuchome@suse.cz
- ask for CurrentButton property of RadioButtonGroup (#345490)
- 2.16.4
* Tue Nov 13 2007 jsuchome@suse.cz
- read /etc/security/pam_mount.conf.xml with ag_anyxml (#332187)
- 2.16.3
* Thu Nov  8 2007 jsuchome@suse.cz
- allow '\' in root's password (#337606)
- removed dependency on yast2-network via DSL module (#339027)
- 2.16.2
* Thu Nov  1 2007 jsuchome@suse.cz
- do not include default 'lxuser' name in the list of suggestions
- 2.16.1
* Fri Oct 19 2007 jsuchome@suse.cz
- check for empty lines in passwd/group/shadow (#333305)
- 2.16.0
* Fri Sep 21 2007 jsuchome@suse.cz
- enable cryted directories for new users (#326794)
- 2.15.38
* Tue Aug 21 2007 jsuchome@suse.cz
- testsuite is back (removed in 2.13.24)
- added UsersPasswd::SetBaseDirectory (called from testsuite)
- 2.15.37
* Fri Aug 17 2007 jsuchome@suse.cz
- use Perl built-ins instead of SCR (patch by locilka, #266179)
- 2.15.36
* Thu Aug  9 2007 jsuchome@suse.cz
- if quota is not configured, tell user how to do it
- help text for Test Keyboard Layout entry (#297163)
- 2.15.35
* Mon Jul 30 2007 jsuchome@suse.cz
- fixed help text (taroth)
- 2.15.34
* Thu Jul 26 2007 jsuchome@suse.cz
- added text entry for testing keyboard in inst_root (F120215)
- 2.15.33
* Wed Jul 25 2007 jsuchome@suse.cz
- Write function from plugin API is now called also on deleted
  users (currently only local)
- added universal "plugin_modified" key to check whether user
  data were modified by plugin
* Wed Jul 11 2007 jsuchome@suse.cz
- added plugin for user and group quotas (F120106)
* Mon Jun 18 2007 jsuchome@suse.cz
- Authentication dialog: lazy checking if packages are available
  saves some time (#273013)
- 2.15.32
* Mon Jun 18 2007 jsuchome@suse.cz
- fix checking autologin status during second stage (#285017)
- 2.15.31
* Tue Jun 12 2007 jsuchome@suse.cz
- additional warning in case of user name conflict (#228283)
- 2.15.30
* Mon Jun 11 2007 jsuchome@suse.cz
- ask for disabling autologin when adding new user (#166228)
- 2.15.29
* Fri May 25 2007 jsrain@suse.cz
- removed outdated translations from .desktop-files (#271209)
* Thu May 24 2007 jsuchome@suse.cz
- check for crypted directories modifications before offering
  'cryptconfig' installation (#274861)
- 2.15.28
* Wed May 23 2007 jsuchome@suse.cz
- use LDAPInitWithTLSCheck function for init - offer fallback to
  unencrypted connection (#246397)
- 2.15.27
* Fri May 11 2007 jsuchome@suse.cz
- during autoinstallation, do not touch already created directories
  (#272744)
- 2.15.26
* Fri May  4 2007 varkoly@suse.de
- Bug 269867 - build cycle between yast2-users and yast2-mail
- 2.15.25
* Fri Apr 20 2007 jsuchome@suse.cz
- check more values in /etc/shadow for -1 (#259896)
- display -1 correctly in the UI (#259896)
- 2.15.24
* Thu Apr 19 2007 jsuchome@suse.cz
- import YaST::YCP in Perl modules (#265875)
- 2.15.23
* Thu Apr 19 2007 jsuchome@suse.cz
- correct fix of writing -1 to /etc/shadow (#265704)
- 2.15.22
* Fri Apr 13 2007 jsuchome@suse.cz
- do not write shadowInactive value of -1 to /etc/shadow (#259896)
- check for /etc/security/pam_mount.conf presence before reading from it
- 2.15.21
* Wed Apr  4 2007 jsuchome@suse.cz
- do not ask for password when user doesn't have encrypted home
  directory (#259874)
- correctly find image and key files of crypted home directory (#259880)
- 2.15.20
* Thu Mar 29 2007 jsuchome@suse.cz
- check if ypbind is installed before reading service status (#256407)
- 2.15.19
* Mon Mar 26 2007 jsuchome@suse.cz
- correctly read minimal password length, if set to 0 (#257075)
- do not throw away possible LDAP error message (UsersLDAP.pm)
- during firstboot, show the same behaviour as in 2nd stage
- 2.15.18
* Mon Mar 12 2007 jsuchome@suse.cz
- call cryptconfig again when home directory was renamed (#252325)
- 2.15.17
* Wed Feb 28 2007 jsuchome@suse.cz
- ask for current user password for any change with crypted
  directory (#242531)
- correctly change the password for directory image (#242531)
- 2.15.16
* Mon Feb 26 2007 jsuchome@suse.cz
- fixed usage of new Package::Available
- 2.15.15
* Fri Feb 23 2007 jsuchome@suse.cz
- include documentaion for YaPI's USERS.pm (#248203)
- 2.15.14
* Thu Feb 22 2007 jsuchome@suse.cz
- do not ask if package is available when it is not possible
  to access installation source (#225484)
- check if package is installed before checking if it is available
- 2.15.13
* Wed Feb 21 2007 jsuchome@suse.cz
- implemented disabling of crypted home directories (#242531)
- when deleting crypted home, disable pam_mount
- 2.15.12
* Wed Feb 14 2007 jsuchome@suse.cz
- enable bigger size of encrypted directory (#244631)
- 2.15.11
* Tue Feb 13 2007 jsuchome@suse.cz
- fixed autoyast schema file
- 2.15.10
* Mon Feb  5 2007 jsuchome@suse.cz
- check the default group of user from previous installation (#239688)
- 2.15.9
* Thu Feb  1 2007 jsuchome@suse.cz
- fixed inst_auth workflow when "Read user data from previous installation"
  is checked but on user selected (#240287)
- 2.15.8
* Fri Jan 26 2007 jsuchome@suse.cz
- adapt inst_auth dialog layout for ncurses (#238726)
- fixed crypted directories handling on user name change and
  directory resize (#235097)
- ConvertMap: check for modifications before analyzing the attributes
- 2.15.7
* Thu Jan 25 2007 jsuchome@suse.cz
- fixed value for pwdReset attribute (#238254)
- read the values of operational attributes (#238254)
- when adding user, add a new check if plugin should not be applied
- set the correct value for pwdAccountLockedTime attribute (#238712)
- 2.15.6
* Fri Jan 19 2007 jsuchome@suse.cz
- added missing help text for Password Policy Plugin (#236613)
- 2.15.5
* Fri Jan 12 2007 jsuchome@suse.cz
- correctly set home directory mode for LDAP users (F3621)
- allow per-user home directory crypting (F301787)
- 2.15.4
* Fri Jan  5 2007 jsuchome@suse.cz
- fixed help text for "Move home directory" feature
- 2.15.3
* Thu Dec 21 2006 jsuchome@suse.cz
- added checkbox for "Move home directory"  (F300550)
- 2.15.2
* Thu Dec  7 2006 jsuchome@suse.cz
- new LDAP plugins for Password Policy and Shadow Account (F301179)
- when enabling plugins, remove plugin from "plugins_to_remove" list
- help text and wizard caption for authentication settings
- 2.15.1
* Mon Dec  4 2006 jsuchome@suse.cz
- differ GenericName from Name in desktop files (#223549)
- check root password for CA constraints (F300438)
- 2.15.0
* Mon Nov 27 2006 jsuchome@suse.cz
- fixed schema file (#215249)
- 2.14.1
* Wed Nov 22 2006 stbinner@suse.de
- don't repeate Name content as GenericName in .desktop files
* Mon Nov  6 2006 jsuchome@suse.cz
- new version for new product
- 2.14.0
* Thu Oct 26 2006 jsuchome@suse.cz
- schema file moved from autoyast package (#215249)
- 2.13.33
* Tue Oct 24 2006 jsuchome@suse.cz
- fix initialization during read of /etc/group (#213025)
- 2.13.32
* Tue Oct 24 2006 jsuchome@suse.cz
- better check if LDAP user password was modified (#213574)
- 2.13.31
* Mon Sep 25 2006 jsuchome@suse.cz
- do not offer importing users when there are not available (#207973)
- 2.13.30
* Thu Sep 21 2006 jsuchome@suse.cz
- setup Kerberos During Installation (F120214)
- 2.13.29
* Wed Sep 20 2006 jsuchome@suse.cz
- fixed installation failure caused by previous changes (#206839)
- fixed directory path with imported data (F120103)
- 2.13.28
* Tue Sep 19 2006 jsuchome@suse.cz
- added help text for importing users from existing partition
- during installation do not show write progress if nothing was modified
- 2.13.27
* Mon Sep 18 2006 jsuchome@suse.cz
- installation: import users from existing partition (F120103)
- 2.13.26
* Thu Sep 14 2006 ro@suse.de
- added yast2-core-devel to BuildRequires
* Thu Sep  7 2006 jsuchome@suse.cz
- minor fixes in help text (#203819)
- allowed changing of new user's home mode and default umask (F3621)
- fixed wrong usage of Progress->set
- fixed setting of user's default group (#203761)
- 2.13.25
* Thu Sep  7 2006 jsuchome@suse.cz
- enhanced writing performance using UserPasswd.pm (#148482, F301176)
- because of UserPasswd.pm, disabled the tests relying on input data
- 2.13.24
* Wed Aug 16 2006 jsuchome@suse.cz
- leave default when CHARACTER_CLASS is not in /etc/login.defs (#199476)
- 2.13.23
* Tue Aug  1 2006 jsuchome@suse.cz
- fixed testsuite (recent change in FileUtils.ycp)
- 2.13.22
* Tue Jul 25 2006 jsuchome@suse.cz
- allow usage of empty passwords (#144724)
- allow "x" and "!" values for passwords (#148464)
- show more descriptive help text about password contents (#146533)
- 2.13.21
* Tue Jul 11 2006 jsuchome@suse.cz
- escape '@' to fix creating pot-file
- 2.13.20
* Thu Jun 29 2006 jsuchome@suse.cz
- more characters allowed in password (#175706, #186833)
- enhanced checking for palindroms in passwords (#144725)
- returned missing part of help text about login
- added UserPasswd.pm module which can enhance writing performance (#148482)
- fixed layout of root password dialog (#164803)
- removed Frame from Login Settings popup (#179788)
- do not remove runme_at_boot (it's task for other parts of YaST)
- user regular expressions for text matching
- 2.13.19
* Mon May 22 2006 jsuchome@suse.cz
- fixed modifying of default group for new users (#176513)
- 2.13.18
* Tue May  9 2006 gs@suse.de
- show root password confirmation field of equal length (bug #164803)
- 2.13.17
* Wed Mar 15 2006 jsuchome@suse.cz
- inst_auth: samba is now Windows Domain Membership (text change)
- 2.13.16
* Tue Mar 14 2006 jsrain@suse.de
- aded support for eDirectory LDAP during instyallation
- 2.13.15
* Thu Feb 23 2006 jsuchome@suse.cz
- correctly assign owners of LDAP users's home directories (#153078)
- Export group's GID for autoyast (#152265)
- 2.13.14
* Mon Feb 20 2006 jsuchome@suse.cz
- reduced BuildRequires
- 2.13.13
* Mon Feb  6 2006 jsuchome@suse.cz
- fix bad chacking for duplicate UID (#146477)
- 2.13.12
* Fri Jan 27 2006 jsuchome@suse.cz
- merged texts from proofreading
- 2.13.11
* Thu Jan  5 2006 jsuchome@suse.cz
- user plugins: enable showing warning message (#58660)
- 2.13.10
* Thu Jan  5 2006 jsuchome@suse.cz
- inst_auth: check if NetworkManager is managing network
* Fri Dec  2 2005 jsuchome@suse.cz
- fixed Import (#136671) by removing forgotten line from old version
- 2.13.9
* Thu Dec  1 2005 jsuchome@suse.cz
- fix all GetGroupByName calls (#136267) + added test
- 2.13.8
* Mon Nov 28 2005 jsuchome@suse.cz
- autoinstallation: show system users and groups by default (#135486),
  do not filter out group "users"
- 2.13.7
* Wed Nov 16 2005 jsuchome@suse.cz
- allow non-unique UID's for users and GID's for groups (feature #300162)
- 2.13.6
* Thu Oct 27 2005 jsuchome@suse.cz
- user plugins: fixed call of Summary function (#130707),
  better check for restrictions
- 2.13.5
* Thu Oct 13 2005 jsuchome@suse.cz
- after renaming user: move home correctly, update autologin (#127561)
- 2.13.4
* Fri Sep 30 2005 jsuchome@suse.cz
- correcly call selected plugins from Plugin tab (#119593)
- 2.13.3
* Thu Sep 29 2005 jsuchome@suse.cz
- generate the home directory for LDAP users correctly (#119012)
- 2.13.2
* Tue Sep 27 2005 jsuchome@suse.cz
- set correctly minimal UID and GID from /etc/login.defs (#119006)
- 2.13.1
* Fri Sep 16 2005 jsuchome@suse.cz
- added missing comments for translators
- inform user about more characters allowed in password (#106714)
- 2.13.0
* Wed Aug 24 2005 jsuchome@suse.cz
- allow some more characters to be included in password (#106714)
- 2.12.8
* Tue Aug 23 2005 jsuchome@suse.cz
- fixed allignment of dialog header
- removed yast2-installation from NFB (#106608)
- 2.12.7
* Thu Aug 11 2005 jsuchome@suse.cz
- fixed setting of default group for new users (#104113)
- 2.12.6
* Thu Aug  4 2005 jsuchome@suse.cz
- installation: do not reset autologin status after Back (#99003)
- 2.12.5
* Tue Aug  2 2005 jsuchome@suse.cz
- start main sequence directly from inst_user
  (which enables checking for parameters, e.g. "enable_back")
- 2.12.4
* Thu Jul 28 2005 jsuchome@suse.cz
- do not re-generate home directory when username wasn't changed
- do not set autologin automatically after Back (#99003)
- 2.12.3
* Tue Jul 12 2005 jsuchome@suse.cz
- fixed cloning users (#94340)
- 2.12.2
* Tue May 17 2005 jsuchome@suse.cz
- fixed texts from proofreading (rwalter)
* Tue Apr 26 2005 jsuchome@suse.cz
- better fix for #76404
- GDM also supports Autologin (#74198) - adapted help texts and tests
- 2.12.1
* Tue Apr 19 2005 jsuchome@suse.cz
- added support for "rootpassword=ask" option for autoinstallation
  (#76404)
- adapted for new ProductFeatures interface
- 2.12.0
* Fri Mar  4 2005 jsuchome@suse.cz
- autoyast: do not import groups that already exist as new
* Fri Feb 25 2005 jsuchome@suse.cz
- fixed buttons hiding/showing during installation (#66589)
* Mon Feb 21 2005 jsuchome@suse.cz
- adapted testsuite for new ProductFeatures variable
- 2.11.14
* Mon Feb 21 2005 jsuchome@suse.cz
- 2.11.13
* Thu Feb 17 2005 jsuchome@suse.cz
- do not chown directory to old UID (#50971)
* Mon Feb 14 2005 jsuchome@suse.cz
- fixed help text
- 2.11.12
* Mon Feb  7 2005 jsuchome@suse.cz
- merged texts from proofreading
- 2.11.11
* Fri Feb  4 2005 jsuchome@suse.cz
- call GROUPADD_CMD if provided in /etc/login.defs
- simplify adding 1st user in installation (= no tabs, #50475)
- 2.11.10
* Mon Jan 31 2005 jsuchome@suse.cz
- call /usr/sbin/useradd.local at the end of adding (#50242)
- 2.11.9
* Mon Jan 31 2005 jsuchome@suse.cz
- added X-SuSE-YaST-AutoInstRequires to desktop file (nashif)
* Fri Jan 28 2005 jsuchome@suse.cz
- 2.11.8
* Fri Jan 28 2005 jsuchome@suse.cz
- update table items correctly during installation
- fixed deleting users from command line
- autoyast: enable creating groups when gid is not provided
- autoyast fix: remove internal cache when importing (#50265)
- write empty vardir/users.ycp file if not present
- fixed button labels of 'first user screen' during installation
* Mon Jan 24 2005 nashif@suse.de
- Set arguments according to new installation workflow interface
* Fri Jan 21 2005 jsuchome@suse.cz
- offer adaptation of home directory when user name was changed
- 2.11.6
* Wed Jan  5 2005 jsuchome@suse.cz
- use tabs in Edit User and Edit Group dialogs
- enable list values for LDAP attributes (cn, sn, givenname)
- 2.11.5
* Wed Dec 15 2004 jsuchome@suse.cz
- do not show Abort button in pseudo-popups
- adapt to current Progress behaviour
- do not abort installation from 'User Management' screen
- special parameters for modules called from 'Data Sources' dialog
- 2.11.4
* Tue Dec  7 2004 jsuchome@suse.cz
- fixed helptext: group password is necessary for non-members (#48997)
* Wed Nov 24 2004 jsuchome@suse.cz
- use UMASK from /etc/login.defs when creating new directories (#48372)
- 2.11.3
* Mon Nov 15 2004 jsuchome@suse.cz
- fix of creating custom user/group filter (#45263)
- fix of initializing LDAP in YaPI (#45898)
- 2.11.2
* Thu Nov  4 2004 jsuchome@suse.cz
- lookup's and select's replaced by brackets
- fixed wrong message during group password checking (#45268)
- 2.11.1
* Fri Oct 29 2004 jsuchome@suse.cz
- adapted for new Mode:: interface
- used common texts from Message module
- 2.11.0
* Mon Oct  4 2004 jsuchome@suse.cz
- do not read settings from Security module if it were already modified
  (#46545)
* Wed Sep 29 2004 jsuchome@suse.cz
- do not discard local users added from rpm scripts during
  autointstallation (#46269)
- 2.10.10
* Wed Sep 29 2004 jsuchome@suse.cz
- do not allow non-ASCII characters in user/groupname (#46347)
- 2.10.9
* Fri Sep 17 2004 jsuchome@suse.cz
- correct initialization of what to show in Summary (#45536)
- 2.10.8
* Wed Sep 15 2004 jsuchome@suse.cz
- correctly check presence of groupname in group password (#45268)
* Wed Sep 15 2004 jsuchome@suse.cz
- disable autologin for deleted user (#45261)
* Fri Sep 10 2004 jsuchome@suse.cz
- exit with warning when creating backup files failed
  (this can happen when there is no space left: #44784)
- 2.10.7
* Mon Sep  6 2004 jsuchome@suse.cz
- adapted for new autoyast behaviour (#44660)
- 2.10.6
* Thu Sep  2 2004 jsuchome@suse.cz
- added new system user names for translation (passwd.ycp)
* Mon Aug 23 2004 jsuchome@suse.cz
- 2.10.5
* Tue Aug 17 2004 jsuchome@suse.cz
- correctly check if NIS server is present (#43889)
- adapted testsuite
* Wed Aug 11 2004 jsuchome@suse.cz
- fix: wrong call of Message module from perl
- do not touch /etc/group when only user was added (+adapted testsuite)
* Tue Aug 10 2004 jsuchome@suse.cz
- merged proofread texts
* Tue Aug  3 2004 jsuchome@suse.cz
- adapted to current CWM::ShowAndRun interface
- show default group for LDAP user although group is not LDAP (#43433)
- properly initialize "enabled" status of user
- adapted to current LdapPopup::EditAttribute interface
- 2.10.4
* Fri Jul 30 2004 jsuchome@suse.cz
- audio,uucp,dialout groups are not added as default (#43329)
- removed check for Mode::live_eval
- add warning when changing password encryption type on NIS server
- fixed testsuite
- 2.10.3
* Mon Jul 26 2004 jsuchome@suse.cz
- use Message module for common messages
- use Package module instead of Require
- crypt group passwords using GROUP_CRYPT from /etc/default/passwd
- 2.10.2
* Tue Jul 20 2004 jsuchome@suse.cz
- change owner of home directory of user with modified UID number (#43132)
- updated testsuite
* Mon Jul 19 2004 jsuchome@suse.cz
- enable short passwords for users (#43033)
- enable starting Samba client from authentization dialog (installation)
* Fri Jul 16 2004 jsuchome@suse.cz
- advanced check for user/group name contents (#43053)
* Wed Jul 14 2004 jsuchome@suse.cz
- LDAP users: initially, read only minimal set of attributes; the rest
  is read in Edit function when it is called for first time
- use Ldap::GetRequiredAttributes for geting required attributes
  of an object class
* Mon Jul 12 2004 jsuchome@suse.cz
- fix of editing the LDAP user or group that was just added (#42777)
- 2.10.1
* Mon Jul 12 2004 jsuchome@suse.cz
- enhanced popup for creating LDAP search filter
* Tue Jun 29 2004 jsuchome@suse.cz
- enable/disable user checkbox (#32587)
- enable creating of empty home (#35466)
- check group passwords
* Mon Jun 21 2004 jsuchome@suse.cz
- command-line: ask for password, if not given
- clear nscd cache also if LDAP users/groups were modified (#41648)
* Tue Jun 15 2004 jsuchome@suse.cz
- command-line: group management, LDAP support
- 2.10.0
* Wed Jun  9 2004 jsuchome@suse.cz
- YaPI: correct initialization of LDAP configuration (#41806, #41850)
- 2.9.38
* Thu May 27 2004 jsuchome@suse.cz
- read LDAP again when clicked `back during installation (#41299)
- crypt group passwords (#41300)
- 2.9.37
* Wed May 26 2004 jsuchome@suse.cz
- LDAP: create correct object classes for groupUniqueOfNames (#41232)
- 2.9.36
* Tue May 25 2004 jsuchome@suse.cz
- fixed testsuite (typo in ProductFeatures.ycp: #41038)
* Mon May 24 2004 jsuchome@suse.cz
- autoyast: store user password during cloning users (#41026)
- 2.9.35
* Thu May 20 2004 jsuchome@suse.cz
- fixed quoting in YCP paths (#40867) + adapted testsuite
* Wed May 19 2004 jsuchome@suse.cz
- YaPI: added $VERSION and @CAPABILITIES (#40796)
- adapted to new +/- lines handling in ag_passwd (#40571)
- /var/lib/nobody can be used by myltiple users (#40365)
- do not move home directory if the new one already exists
- 2.9.34
* Fri May 14 2004 jsuchome@suse.cz
- during deleting LDAP user/group, read the list of its plugins (#40561)
- 2.9.33
* Wed May 12 2004 jsuchome@suse.cz
- enable '$' as a part of LDAP 'uid' attribute (Samba wants it: #40433)
- YaPI: enhanced testsuite
* Tue May 11 2004 jsuchome@suse.cz
- fixed calling of gettext from Perl modules (#40160)
- 2.9.32
* Fri May  7 2004 jsuchome@suse.cz
- use correct translation function (#39954)
* Thu May  6 2004 jsuchome@suse.cz
- LDAP: do not save unchanged values (#39472)
* Wed May  5 2004 jsuchome@suse.cz
- inst_user: call users after ldap-client if ldap-client uses previously
  configured server (#39901)
- Enable/Disable functions for LDAP user
- improved logging for Perl modules
- 2.9.31
* Tue May  4 2004 jsuchome@suse.cz
- merged in proofread text
* Thu Apr 29 2004 jsuchome@suse.cz
- enhanced plugin dialog (enables adding + removing)
- all YaPI functions should be functional
* Tue Apr 27 2004 jsuchome@suse.cz
- plugins: enable deleting of objectClass (#38984)
- plugins: error handling (#38983), removing (#38984)
- create defult base in LDAP tree if it doesn't exist (#39476)
- 2.9.30
* Wed Apr 21 2004 arvin@suse.de
- added special sles screen for user authentication
* Tue Apr 20 2004 jsuchome@suse.cz
- fixed build
- 2.9.29
* Thu Apr 15 2004 jsuchome@suse.cz
- fix: enable user membership management for LDAP groups (#38919)
- fix: add shadowAccount attribute if not present (#38467)
- fix: save encoding settings during installation
- fix: read LDAP users at module start when they are in custom set
- plugins: differ between plugin for users and groups
- 2.9.28
* Tue Apr  6 2004 jsuchome@suse.cz
- fix: check for shadowAccount attribute of LDAP users (#38467)
- 2.9.27
* Mon Apr  5 2004 jsuchome@suse.cz
- fix: correct initial ID for LDAP groups (#38250)
- 2.9.26
* Fri Apr  2 2004 jsuchome@suse.cz
- changed license to GPL
- 2.9.25
* Fri Apr  2 2004 jsuchome@suse.cz
- fix: enable deleting groups with long name (#38006)
- 2.9.24
* Wed Mar 31 2004 jsuchome@suse.cz
- fix: build table items during installation (#37670)
* Tue Mar 30 2004 jsuchome@suse.cz
- fix: update plugin list after PluginPresent (rhafer)
- fix: after 'Write changes now', enable delete previously added user
- fix: do not set both groupOfNames and groupOfUniqueNames for group
- fix: widget difinition for CWM
- YaPI: UserDisable, UserEnable, GroupModify
- 2.9.23
* Mon Mar 29 2004 jsuchome@suse.cz
- plugins: check if plugin is defined for given user/group ('PluginPresent')
- plugins: use 'plugins_to_remove' flag
- 2.9.22
* Thu Mar 25 2004 jsuchome@suse.cz
- autoyast: properly handle 'shadowlastchange' value (#36804)
* Wed Mar 24 2004 jsuchome@suse.cz
- YaPI: UserModify
- LDAP configuration: new attribute names (with 'suse' prefix)
* Tue Mar 23 2004 jsuchome@suse.cz
- YaPI: UserAdd, UserDelete, UserGet, UsersGet
- autoyast fix: show empty user password in config mode (#36726)
- Users::Read and Users::Write now return error message, not boolean
* Tue Mar 23 2004 jsuchome@suse.cz
- autoyast fix: do not import groups with gid -1, do not forget to
  create user home directories
  (+ probably fixed #35600)
- 2.9.21
* Mon Mar 22 2004 jsuchome@suse.cz
- use only lowercase user/group attribute names
  (adapted also agent-nis and testusite for this change)
* Mon Mar 22 2004 jsuchome@suse.cz
- do not lose data of first user during installation (#36543)
- 2.9.20
* Fri Mar 19 2004 jsuchome@suse.cz
- plugins: support all current calls (Add/Edit/Write) also for groups
* Fri Mar 19 2004 mvidner@suse.cz
- added AGENT_LIBADD so that agents work from standalone Perl
* Thu Mar 18 2004 jsuchome@suse.cz
- adapted for the new perl bindings
- 2.9.19
* Tue Mar 16 2004 jsuchome@suse.cz
- plugins: call AddBefore, EditBefore also from GUI client
* Tue Mar 16 2004 jsuchome@suse.cz
- autoinstall fixes: do not lost gid, check if password should be crypted
* Mon Mar 15 2004 jsuchome@suse.cz
- plugins: changed calling convention (call only default ones,
    saved in LDAP configuration, unless directly choosed)
  internal information (like user type, type of modification)
    moved to config map
  many minor fixes
- 2.9.18
* Mon Mar 15 2004 jsuchome@suse.cz
- changed internal key names: "username" -> "uid", "groupname" -> "cn"
- adapted testsuite
- 2.9.17
* Sat Mar 13 2004 arvin@suse.de
- require yast2-perl-bindings (bug #35914)
* Wed Mar 10 2004 jsuchome@suse.cz
- agent-passwd moved to yast2-pam package
- 2.9.15
* Wed Mar 10 2004 jsuchome@suse.cz
- .pm files adapted for new perl-bindings (use array reference, not array)
* Wed Mar 10 2004 jsuchome@suse.de
- disabled testsuite
- 2.9.14
* Wed Mar 10 2004 sh@suse.de
- V 2.9.13
- Migration to new wizard
* Mon Mar  8 2004 jsuchome@suse.cz
- set wizard icon
* Mon Mar  8 2004 jsuchome@suse.cz
- fix: check group name
- fixes of default LDAP plugin
- 2.9.12
* Thu Mar  4 2004 jsuchome@suse.cz
- plugins: differs user from groups (=2 map parameters to every function)
    check plugin availability for given user/group type,
    "rest of LDAP attributes" is default plugin,
- LDAP: check attributes required by the LDAP schema
* Wed Mar  3 2004 jsuchome@suse.cz
- LDAP: configurable group member attribute (member vs. uniqueMember)
- check for errors in config files (/etc/passwd) and warn user
- error popups when LDAP writing fails
- 2.9.11
* Wed Mar  3 2004 jsuchome@suse.cz
- fix of inst_root client
* Tue Mar  2 2004 jsuchome@suse.cz
- call LDAP configuration from Users
- enable writing without finish
* Mon Mar  1 2004 jsuchome@suse.cz
- merged texts from proofread
- change of plugin handling
- 2.9.10
* Thu Feb 26 2004 jsuchome@suse.cz
- fixed calling from control center (#35006)
* Wed Feb 25 2004 jsuchome@suse.cz
- initial support for plugins
* Mon Feb 23 2004 jsuchome@suse.cz
- error messages after failure of system files (/etc/passwd) read
- more autoyast fixes (export only changed values)
* Fri Feb 20 2004 jsuchome@suse.cz
- do not break special files (e.g. /dev/null) when set as home dir
* Fri Feb 20 2004 jsuchome@suse.cz
- autoyast interface
- 2.9.9
* Wed Feb 18 2004 jsuchome@suse.cz
- do not import Kerberos,Samba,Nis
* Mon Feb 16 2004 jsuchome@suse.cz
- fix: enable whitespace in passwords (#34590)
* Mon Feb 16 2004 jsuchome@suse.cz
- support for autoyast (initial for new module backend)
- 2.9.8
* Mon Feb 16 2004 jsuchome@suse.cz
- fixed testsuite
- fixed needforbuild
* Fri Feb 13 2004 jsuchome@suse.cz
- enhanced cmd-line interface support
- fixes: multiple changes of uid,username,home,gid,groupname
* Wed Feb 11 2004 jsuchome@suse.cz
- agent-passwd: correct default values, store password from shadow
- save + lines at the end of config files when NIS is enabled
- LDAP: rename objects, configure search filters
- corrected helptexts
- 2.9.7
* Wed Feb 11 2004 jsuchome@suse.cz
- fix: correct path to config files
* Tue Feb 10 2004 jsuchome@suse.cz
- LDAP: write groups
- new file: UsersRoutines.pm
* Mon Feb  9 2004 jsuchome@suse.cz
- more functions for LDAP support (write users, read groups)
- fixed installation clients
- 2.9.6
* Mon Feb  9 2004 arvin@suse.de
- removed config files (*.y2cc)
* Tue Feb  3 2004 jsuchome@suse.cz
- agent for NIS users/groups
- initial LDAP support (with new Perl backend)
* Mon Feb  2 2004 jsuchome@suse.cz
- new backend, written in Perl
- 2.9.4
* Mon Jan 19 2004 jsrain@suse.de
- merged the new interpreter branch
* Mon Dec  1 2003 jsuchome@suse.cz
- syntax fixes for new interpreter
- 2.9.3
* Thu Nov 27 2003 jsuchome@suse.cz
- LDAP: added crypting passwords via slappaswd
* Tue Nov 25 2003 jsuchome@suse.cz
- fix for LDAP: ignore non-existent attribute, until it is set again
  (caused "No such attribute" error when agent tried
  to remove actualy non-existent one from user/group entry)
* Tue Nov 18 2003 jsuchome@suse.cz
- used UI:: builtins for file selection widgets
- migrated to doxygen
- 2.9.2
* Mon Oct  6 2003 jsuchome@suse.cz
- basic command-line interface
- removed CallModule calls
- 2.9.1
* Fri Oct  3 2003 jsuchome@suse.cz
- 'fullname' attribute renamed to 'cn' to follow LDAP specifications
* Wed Oct  1 2003 jsuchome@suse.cz
- autologin: added configuration popup (initial), used Autologin module
* Mon Sep 29 2003 jsuchome@suse.cz
- properly differ between local/system users (#31515),
  manage new variables from /etc/login.defs,
  enable change of user/group type (by changing uid/gid)
- 2.9.0
* Tue Sep 23 2003 jsuchome@suse.cz
- run suseconfig after writing autologin value (#31470)
- 2.8.20
* Fri Sep 19 2003 jsuchome@suse.cz
- fixed: non-ISO-1 chars in fullname not shown (#31405)
- fixed testsuite
- 2.8.19
* Thu Sep 18 2003 nashif@suse.de
- fixed testsuite
- 2.8.18
* Thu Sep 18 2003 jsuchome@suse.cz
- disable also login without passwords if there are more users (#31141)
- recode error messages from cracklib to UTF-8
- 2.8.17
* Wed Sep 17 2003 jsuchome@suse.cz
- disable autologin when there are more users (#31141)
- 2.8.16
* Mon Sep 15 2003 jsuchome@suse.cz
- in autoyast config mode, clear password entries for system users (#30573)
- fixed testsuite
- 2.8.15
* Sat Sep 13 2003 nashif@suse.de
- Turn off progress during autoinstallation
* Thu Sep 11 2003 jsuchome@suse.cz
- layout of first dialog (#29389)
* Wed Sep 10 2003 jsuchome@suse.cz
- check if autologin is available (only works for KDM, bug #30385)
* Tue Sep  9 2003 jsuchome@suse.cz
- flush /etc/sysconfig/displaymanager after write during installation
  (autologin bug #30124)
- 2.8.14
* Mon Sep  8 2003 jsuchome@suse.cz
- check if NIS was enabled while module is running (#30256)
* Mon Sep  8 2003 jsuchome@suse.cz
- do not create root's home direcotry in autoyast install (#30186)
* Fri Sep  5 2003 jsuchome@suse.cz
- save changed autologin status (#30105)
* Fri Sep  5 2003 jsuchome@suse.cz
- merged in proofread texts
- 2.8.13
* Tue Sep  2 2003 jsuchome@suse.cz
- fixed helptexts
* Mon Sep  1 2003 jsuchome@suse.cz
- LDAP users: chek for object class existence
* Mon Sep  1 2003 jsuchome@suse.cz
- removed checking for kerberos
- rearanged buttons for 'add user dialog' during installation
  (from sh@suse.de, bug #29389)
- 2.8.12
* Sun Aug 31 2003 arvin@suse.de
- use Popup::ConfirmAbort
* Mon Aug 25 2003 jsuchome@suse.de
- enabled autologin (#29207)
* Fri Aug 22 2003 jsuchome@suse.de
- 2.8.11
* Wed Aug 20 2003 jsuchome@suse.de
- removed redundant "initialization dialog" (#28779)
- fixed help text
* Wed Aug 13 2003 jsuchome@suse.de
- added new system user names for translation (passwd.ycp)
- 2.8.10
* Mon Aug 11 2003 jsuchome@suse.de
- proofread texts, 1st round
- 2.8.9
* Wed Aug  6 2003 jsuchome@suse.de
- fixed: importing empty group (#28491)
- do not abort from Read in installation mode
* Thu Jul 24 2003 msvec@suse.de
- added yast2-pam to needededforbuild
- 2.8.8
* Thu Jul 24 2003 arvin@suse.de
- adapted neededforbuild to changes in yast2-security
* Thu Jul 17 2003 jsuchome@suse.de
- system settings (/etc/login.defs etc.) are read from Security module
- helptexts
* Mon Jul 14 2003 jsuchome@suse.de
- fix on inst_user dialog (#27859)
- fix: proper saving of "Expiration date" (#27863)
* Thu Jul 10 2003 jsuchome@suse.de
- secondary groups for new users saved in /etc/default/useradd
- LDAP users and groups management:
    password length checks (length defined in LDAP configuration)
    saving last used Id to LDAP config object
    solved LDAP groups (groupOfUniqueNames cannot be empty)
- adapted testsuite
- 2.8.6
* Fri Jun 27 2003 jsuchome@suse.de
- ldap defaults read from config modules stored in LDAP directory
- for manipulation with LDAP, used ldap-client API
- possibility to re-read LDAP settings after call of ldap-client
- fix: changing home directory
- 2.8.5
* Fri Jun 20 2003 jsuchome@suse.de
- adapted to new agent-ldap (using c++ API)
- added missing imports
- adapted testsuite
- adapted to Label/Popup modules
- 2.8.4
* Fri Jun 20 2003 mvidner@suse.cz
- Requires yast2-mail-aliases, which has been split off yast2.rpm
* Wed Jun  4 2003 jsuchome@suse.de
- added agent-crack for checking passwords strength (bug #21266)
- 2.8.3
* Fri May 23 2003 jsuchome@suse.de
- warning when username has uppercase letters (bug #26409)
* Mon May  5 2003 jsuchome@suse.de
- popup for setting LDAP search filters
- agent-ldap: check if filter is correct
* Wed Apr 30 2003 jsuchome@suse.cz
- browse buttons for default home and skeleton directories
- popup for LDAP search filter
* Wed Apr 23 2003 jsuchome@suse.cz
- LDAP users: edit shadow setting, "more settings" dialog
- agent-ldap: change DN after change of username (groupname)
* Tue Apr 22 2003 jsuchome@suse.de
- only one field for fullname (#21175)
- "Browse" button for home directory
* Thu Apr 17 2003 jsuchome@suse.de
- check passwords max length (#13291)
- home directories (enable re-using of directories marked for deletion)
- managing group mambership of ldap users
- ldap error messages
- 2.8.2
* Mon Apr 14 2003 jsuchome@suse.de
- new "agent-uid" for testing uid/username existence
- proposed some layout changes: separate dialogs for auth and encryption
- new "agent-ldap" for LDAP user/group operations (don't use "cpu" more)
- adapted testsuite
* Thu Mar 27 2003 jsuchome@suse.de
- fixes in LDAP users management:
    display error messages, use spaces in fullname, don't ask for
    delete directory if it is not present
- don't save users when no really change was done (ReallyModified())
- changed abort popup
- 2.8.1
* Tue Mar 25 2003 jsuchome@suse.de
- adapted to Require interface
- change ownership only when necessary (#25200)
- check for duplicate values in /etc/passwd and other files (#25394)
- remove temporary files with user data directly after reading
* Mon Mar 24 2003 jsuchome@suse.de
- corrected texts (#25130)
- confirmation dialog when no user added in during installation (#25072)
- password length description (#24152)
- 2.8.0
* Wed Mar 12 2003 jsuchome@suse.de
- missing texts for translations (#25189)
* Mon Mar 10 2003 jsuchome@suse.de
- enable uppercase in user/groupnames (#24891)
- removed text which was missed for translations
* Wed Mar  5 2003 jsuchome@suse.de
- fix: cloning users during autoinstallation (#24629)
- fix: creating homes during autoinstallation (#24731)
- fix: remove nscd cache before chown (#24748)
- 2.7.20
* Mon Mar  3 2003 jsuchome@suse.de
- merged proofreaded texts
- inst_auth: fix network devices testing (#24004) - msvec@suse.cz
- 2.7.19
* Thu Feb 27 2003 jsuchome@suse.de
- added popup for confirmation of short root's password (#24294)
- inst_auth: ldap/nisplus options not greyed, but removed if package
    is not available (#24358)
- fix: first user is displayed more times after multiple next & back
    (during installation, bug #24441)
- 2.7.18
* Wed Feb 26 2003 arvin@suse.de
- removed calling of kbuildsycoca since it's now done in
  suseconfig
* Tue Feb 25 2003 jsuchome@suse.de
- fixes of _auto client (nashif@suse.de):
- fix: "user password lost after details menu" (#24231)
- 2.7.17
* Tue Feb 25 2003 arvin@suse.de
- save use of notify events in inst_auth.ycp
* Mon Feb 24 2003 jsuchome@suse.de
- enable re-connecting to ldap server (bug #24198)
* Mon Feb 24 2003 jsuchome@suse.de
- fix: group ownership for home directory not set if group is newly
  created (#24130)
- 2.7.16
* Fri Feb 21 2003 arvin@suse.de
- better text for "abort installation" popup (bug #24019)
* Fri Feb 21 2003 jsuchome@suse.de
- changed text for no user during installation
- fix: LDAP/NIS user cannot be added to local group (#24022)
- function ReadNewSet is now global (used by phone-services, #23961)
- 2.7.15
* Thu Feb 20 2003 jsuchome@suse.de
- added label with current filter (bug #23920)
* Wed Feb 19 2003 jsuchome@suse.de
- inst_auth: check if {ldap,nisplus}-client is available (#23762)
* Mon Feb 17 2003 jsuchome@suse.de
- call "sux kbuildsycoca" after adding user during installation
- inst_auth: check for DSL device
- 2.7.14
* Fri Feb 14 2003 jsuchome@suse.de
- fixed typos in texts
* Thu Feb 13 2003 jsuchome@suse.de
- inst_user: use CallFunction, not CallModule
* Wed Feb 12 2003 jsuchome@suse.de
- additional text corrected
* Tue Feb 11 2003 jsuchome@suse.de
- check for installed {nis,nisplus,ldap}-client module before called
- more checks for new hoe directory
- add user dialog (#23512)
  password and home are not checked when clicking "Details"
- 2.7.13
* Tue Feb 11 2003 nashif@suse.de
- Update shadow settings with new password when importing
* Mon Feb 10 2003 jsuchome@suse.de
- check for Lan in inst_auth
- fix: check if home directory can be created
* Mon Feb 10 2003 jsuchome@suse.de
- proofreaded texts: 3rd round
* Wed Feb  5 2003 jsuchome@suse.de
- inst_user: calling modules after inst_auth dialog
- defaults dialog: small widgets moving
- 2.7.12
* Tue Feb  4 2003 jsuchome@suse.cz
- autoinst: fixed importing user (missing shadow map)
- added progress for LDAP
* Mon Feb  3 2003 jsuchome@suse.de
- NIS+ entry in expert_login
* Fri Jan 31 2003 jsuchome@suse.de
- expert settings for root: used only popup again
- new file inst_auth.ycp: authentication setting during installation
- expert_settings: show NIS in authentication table
- 2.7.11
* Wed Jan 29 2003 jsuchome@suse.cz
- gathered new system users to passwd.ycp (do not use passwd.sh now)
- translations of System users indexed by fullname, not by username
- when adding new user, Next is the default button (#23172)
- merged proofreaded texts
- 2.7.10
* Mon Jan 27 2003 jsuchome@suse.cz
- autoinst fix: do not export group with only cache structures changed
- fix: changing id's more times, check for keys to remove from maps
- adapted testsuite
* Mon Jan 27 2003 jsuchome@suse.cz
- autoinstall: check for imported users without uid's
- changed checkbox "forward root's mail"
- fix: recode gecos for system users when saving
- yast2-security is needed for build
- 2.7.9
* Fri Jan 24 2003 jsuchome@suse.cz
- reading and saving custom settings
- testing for nis via Runlevel module
- fixed sequence in expert dialog
- fix of cursor "bug" (#23048)
- saving only modified customs/defaults
- fixed generating grouplist for nis/ldap
- added tests
- 2.7.8
* Wed Jan 22 2003 jsuchome@suse.de
- autoinstalation: only modified users and groups exported
- encryption settings and password checks read from Security module
- added some checks for password content
- new translation texts
- 2.7.7
* Mon Jan 20 2003 jsuchome@suse.cz
- fix in recoding strings
- function keys (ncurses)
- new user entry (for finger, bug 18270) + helptext
- adapted testsuite
- 2.7.6
* Fri Jan 17 2003 jsuchome@suse.cz
- ldap: enabled modification of email, seting gecos,
    password shouldn't be changed by cpu when editing
* Thu Jan 16 2003 jsuchome@suse.de
- autoinst
- fixed build_additional_users.pl script
* Wed Jan 15 2003 jsuchome@suse.cz
- use cpu_configure from ldap-client to set cpu.cfg values (for LDAP)
- not neccessary to have anonymous access to LDAP server
  (-> ask for password)
- 2.7.5
* Wed Jan  8 2003 jsuchome@suse.de
- fix: created path to home directory if not exist
- check if home directory is mounted (bug #20365)
- check for installed packages
- read speedup (script)
- enabled reading NIS groups
- enabled reading and editing LDAP groups
- 2.7.4
* Wed Dec 18 2002 jsuchome@suse.de
- fixes: missing newlines on write, reading /etc/group, writing shadow
- auth.ycp + expert dialog from inst_root.ycp -> expert_login.ycp
- running expert dialog from main users dialog
- reading speedup
- adding blanks to uid entry in table widget
- 2.7.3
* Mon Dec 16 2002 jsuchome@suse.de
- fixed broken installation sequence
- first fix of #22443 (strange [unicode] characters in curses)
- enabled change of UID (#16084)
- 2.7.2
* Fri Dec 13 2002 jsuchome@suse.de
- new client for authentication: enables running NIS, LDAP, Kerberos modules
- new kerberos module:
  - basic configuration of kerberos client (agent for /etc/krb5.conf)
  - basic PAM settings for pam_krb5
- support for LDAP users:
  - for generating list is the package perl-ldap used
  - anonymous read access to LDAP server is required
  - for modifications, cpu package is used
- script for reading splited, some data can be read later on demand
    (typically NIS/LDAP users)
- autoinstalation
- nis: users, are retrieved with ypcat
- editgroup dialog: 2 widgets of users
- group users (100 will change to 500) is now local (#19253)
- new helptexts
- 2.7.1
* Wed Nov 27 2002 jsuchome@suse.cz
- New version of Users module:
- rewrite of code
- new files structure
- new data structures, enabling faster behaviour
- data structures are pre-builded via perl-script
- data are written directly to config (passwd...) files, not by extern
  tools (useradd etc.)
- dialog for changing /etc/default/useradd values (#14129)
- updated documentation
- etc_default_useradd.scr changed to use ini-agent
- 2.7.0
* Wed Oct  2 2002 mvidner@suse.cz
- Improved the terrible performance for large numbers of users (#20072).
- Fixed #20360 - an error popped up for each NIS user when renaming a group.
- Fixed #20363 - could not add and remove users in a group at the same time.
- Better progress reporting (verbose for 'yast2 users progress_enabled').
- 2.6.30
* Tue Oct  1 2002 jsrain@suse.cz
- fixed sorting of users by UID (#17650)
* Tue Sep 17 2002 lslezak@suse.de
- fixed typo - write "blowfish" instead of "blowhish" to file
  /etc/security/pam_pwcheck.conf (#19741)
- version 2.6.29
* Tue Sep 17 2002 mvidner@suse.de
- Fixed untranslated help text in the control center (#19753).
- 2.6.28
* Wed Sep 11 2002 mvidner@suse.cz
- When displaying only non-system groups, display also "users" (#19253).
- 2.6.27
* Fri Sep  6 2002 jsrain@suse.cz
- fixed provides/obsoletes
- fixed translation of expiration date help (Bug #18601)
- added error popup to avoid deleting remote NIS server user
- 2.6.26
* Thu Sep  5 2002 jsrain@suse.cz
- fixed help text for root password setting
- 2.6.25
* Fri Aug 30 2002 jsrain@suse.cz
- not removing /var/lib/YaST2/runme_at_boot in case of ssh
  installation (Bug #18580)
- redirecting output of yphelper (Bug #18621)
- dixed last p[assword change date for new user (Bug #18601)
- 2.6.24
* Thu Aug 29 2002 jsrain@suse.cz
- fixed building
- 2.6.23
* Mon Aug 26 2002 jsrain@suse.cz
- fixed informations shown during installation (Bug #18331)
- fixed ncurses buttons size (Bug #18251)
- 2.6.22
* Fri Aug 23 2002 jsrain@suse.cz
- fixed help for password encryption selection
- 2.6.21
* Fri Aug 23 2002 jsrain@suse.cz
- fixed provides and obsoletes
- sorting made more effective (and removed where not needed)
- 2.6.20
* Fri Aug 16 2002 jsrain@suse.cz
- fixed kdoc comments
- merged proofread strings
- fixed sorting by UID /GID (Bug #17653)
- 2.6.19
* Fri Aug  9 2002 jsrain@suse.de
- fixed initialization help text (Bug #17542)
- 2.6.18
* Thu Aug  8 2002 jsrain@suse.de
- added more testsuites
- 2.6.17
* Mon Aug  5 2002 jsrain@suse.cz
- added more verbose error logging
- 2.6.16
* Thu Aug  1 2002 jsrain@suse.cz
- fixed reading values from /etc/login.defs
- fixed forwarding root's mail
- allowed to enter custom shell (Bug #10290)
- 2.6.15
* Tue Jul 30 2002 jsrain@suse.cz
- fixed comments for translators
- removed "add user" and "add group" icons from YaST2 conrol center
- 2.6.14
* Fri Jul 26 2002 jsrain@suse.cz
- yast2-security now not needed for running
- 2.6.13
* Mon Jul 22 2002 jsrain@suse.cz
- removed yast2-mail from list of required packages
- fixed root password during installation (Bug #17126)
* Fri Jul 19 2002 jsrain@suse.cz
- Removed yast2-nis from list of required packages
- Merged proofread texts
* Thu Jul 18 2002 jsrain@suse.cz
- Added blowfish password encryption support
* Tue Jul 16 2002 jsrain@suse.cz
- Removed namaspace using for Args and CallFunction
- Added support for seting forwaring root's mail during
  installation
* Mon Jul 15 2002 jsrain@suse.cz
- Fixed installation workflow (Bug #14079)
- Fixed console encoding detection (Bug #16827)
* Fri Jul 12 2002 jsrain@suse.cz
- Fixed detection whether is NIS domain master
* Fri Jul 12 2002 arvin@suse.de
- use proper namespace for Args and CallFunction (#16776)
* Wed Jul 10 2002 jsrain@suse.cz
- Fixed maintenance of users/group for NIS when using other dir
  than /etc for files (Bug #14817)
- Addedf possibility to add non-local users to local groups
  (Bug #15013)
* Tue Jul  9 2002 msvec@suse.cz
- added missing textdomains
- unified textdomains to users
- added translation of system accounts
- 2.6.5
* Thu Jul  4 2002 arvin@suse.de
- moved non binary file to /usr/share/YaST2
* Thu Jul  4 2002 jsrain@suse.cz
- Able to edit password settings (Bug #15841)
- Helps update of Users module
- added yast2-country to requires
- Added testsuite
- Now allowed "=" in password (#15646)
* Tue Jul  2 2002 jsrain@suse.cz
- added the installation files
* Fri Jun 28 2002 arvin@suse.de
- renamed package from yast2-config-users to yast2-users
* Tue Jun 25 2002 jsrain@suse.cz
- Allowed password longer than 8 characters (#9810)
- Fixed changing of home dir UID (#15552)
- Fixed deleting home dir (#10994)
- Added /etc/shadow reading
- Adapted for new result values of Any-agent
* Wed Mar 27 2002 mvidner@suse.cz
- Prevent deleting a currently logged-in user. (#15557)
* Fri Mar  8 2002 jbuch@suse.de
- remove incorrect help text (#14712)
* Fri Mar  8 2002 jbuch@suse.de
- fixed bug - changing password of an existing user
* Fri Mar  8 2002 jbuch@suse.de
- Set focus on userpage to forename field (Bug #14664)
  Use helptext form inst_root.ycp for password (Bug #13383)
* Fri Mar  1 2002 jbuch@suse.de
- use min_pas_len from /etc/login.defs for md5 too
* Thu Feb 28 2002 jbuch@suse.de
- bug 14105: fixed problems with users that have nearly the same
  name
* Tue Feb 26 2002 jbuch@suse.de
- fixed bug 12647 - change the home directory
- in continue mode call the abort Popup from user module (not
  inst_user.ycp)
* Mon Feb 25 2002 jbuch@suse.de
- utf-8 -> UTF-8
  Encodings must be upper case !
* Mon Feb 25 2002 jbuch@suse.de
- fixed module syntax (Users.ycp)
* Mon Feb 25 2002 jbuch@suse.de
- fixed call of pam agent
* Mon Feb 25 2002 jbuch@suse.de
- fixed sequencer bug in the inst-sys
  don't show group nobody
  use value "umask" from /etc/login.defs
* Fri Feb 22 2002 jbuch@suse.de
- raise login name length limit to 32 chars
  fixed bad help text
  fixed SetFocus bugs
  fixed one ShortCut bug
  changed allowed password characters
* Thu Feb 21 2002 lslezak@suse.cz
- fixed bug (#13199) - user configuration in installation
  can be skipped now
- version 2.5.10
* Mon Feb 18 2002 sh@suse.de
- V 2.5.9
- Fixed bug #13518: Keyboard focus not in input field when adding
  user
* Mon Feb 18 2002 sh@suse.de
- V 2.5.8
- Fixed bug #13383: Letters not mentioned as valid chars in help
  text
* Mon Feb 18 2002 kkaempf@suse.de
- use etc_passwd.scr as provided by yast2.rpm.
* Mon Feb 18 2002 kkaempf@suse.de
- provide .scr files in filelist.
* Mon Feb 18 2002 kkaempf@suse.de
- defined any agent config files used here.
- don't use /tmp file but parse command output directly.
* Tue Feb 12 2002 kkaempf@suse.de
- re-enable chown after useradd.local
* Mon Feb 11 2002 nashif@suse.de
- more autoinstall updates
- 2.5.3
* Sun Feb 10 2002 nashif@suse.de
- Adapted for auto-installation
- 2.5.2
* Fri Feb  8 2002 tom@suse.de
- Now the config module is being called from the installation
  workflow.
* Tue Sep 11 2001 jbuch@suse.de
- Fixed error in switching between groups and users
* Sat Sep  8 2001 jbuch@suse.de
- Add the new CheckBox "Also view system users/groups"
- Changed TextEntry for userlist/grouplist to MultiSelectionBox
* Fri Sep  7 2001 jbuch@suse.de
- fixed bug 10290
* Tue Aug 21 2001 jbuch@suse.de
- add yast2-agent-pam to spec file
  replaced fileexist
* Thu Aug  9 2001 jbuch@suse.de
- add crypt md5 password
* Mon Aug  6 2001 jbuch@suse.de
- edit user/group with double click
* Fri May 18 2001 kendy@suse.cz
- fixed MAINTAINER: jbuch@suse.de, not me
* Mon May 14 2001 jbuch@suse.de
- added if( test_mode) for test output
  else the user can read a map saved in the directory /tmp/..
  that contains crypted passwords and other user and group
  informations
* Thu May 10 2001 gs@suse.de
- icons for module Create an user and Create a group added (bug
  7234)
* Mon May  7 2001 jbuch@suse.de
- UI(`GetLanguage()) to UI(`GetLanguage(true))
* Mon May  7 2001 jbuch@suse.de
- new version
* Mon May  7 2001 jbuch@suse.de
- fixed Encoding/Uncoding fullname
* Thu May  3 2001 jbuch@suse.de
- fixed bug 7517 and 7428
* Mon Apr 30 2001 jbuch@suse.de
- add icons for menu; fixed shell bug
* Thu Apr 26 2001 jbuch@suse.de
- add saving group password
* Tue Apr 24 2001 jbuch@suse.de
- check_ycp ok
* Tue Apr 24 2001 jbuch@suse.de
- new menuentry and isnil(..) -> .. != nil
* Tue Apr 17 2001 jbuch@suse.de
- initial
